@@ -403,7 +403,8 @@ Q_SIGNALS:
     /**
      * Is emitted if the URL \a url should be opened in a new inactive tab because
      * the user clicked on a breadcrumb with the middle mouse button or
-     * left-clicked with the ctrl modifier pressed.
+     * left-clicked with the ctrl modifier pressed or pressed return with
+     * the alt modifier pressed.
      */
     void tabRequested(const QUrl &url);
 
@@ -411,14 +412,16 @@ Q_SIGNALS:
      * Is emitted if the URL \a url should be opened in a new active tab because
      * the user clicked on a breadcrumb with the middle mouse button with
      * the shift modifier pressed or left-clicked with both the ctrl and shift
-     * modifiers pressed.
+     * modifiers pressed or pressed return with both the alt and shift modifiers
+     * pressed.
      * @since 5.89
      */
     void activeTabRequested(const QUrl &url);
 
     /**
      * Is emitted if the URL \a url should be opened in a new window because
-     * the user left-clicked on a breadcrumb with the shift modifier pressed.
+     * the user left-clicked on a breadcrumb with the shift modifier pressed
+     * or pressed return with the shift modifier pressed.
      * @since 5.89
      */
     void newWindowRequested(const QUrl &url);
@@ -435,6 +438,14 @@ Q_SIGNALS:
      */
     void urlSelectionRequested(const QUrl &url);
 
+    /**
+     * The internal layout and graphical representation of components has changed,
+     * either after an url change or after a switch between editable mode and
+     * breadcrumb mode
+     * @since 6.11
+     */
+    void layoutChanged();
+
 protected:
 #if !defined(K_DOXYGEN)
     /**
@@ -465,7 +476,11 @@ protected:
 
     void wheelEvent(QWheelEvent *event) override;
 
+    void showEvent(QShowEvent *event) override;
+
     bool eventFilter(QObject *watched, QEvent *event) override;
+
+    void paintEvent(QPaintEvent *event) override;
 #endif
 
 private:
